@@ -2,7 +2,7 @@
 
 import re
 import string
-from typing import List, Optional, cast
+from typing import Any, List, Optional, cast
 
 import contractions
 import spacy
@@ -26,7 +26,7 @@ nlp = spacy.load("en_core_web_sm")
 
 
 def remove_stopwords(tokens: List[str], custom_stopwords: List[str] = []) -> List[str]:
-    """Removes stopwords from the provided list of tokens.
+    """Remove stopwords from the provided list of tokens.
 
     Parameters
     ----------
@@ -47,7 +47,6 @@ def remove_stopwords(tokens: List[str], custom_stopwords: List[str] = []) -> Lis
     >>> remove_stopwords(tokens)
     ['My', 'name', 'Dr', 'Jekyll']
     """
-
     if custom_stopwords:
         stop_words = set(custom_stopwords)
     else:
@@ -181,7 +180,7 @@ def convert_numerals_to_numbers(sentence: str) -> str:
     return " ".join([str(token) for token in tokens])
 
 
-def replace_contractions(sentence: str, **kwargs) -> str:
+def replace_contractions(sentence: str, **kwargs: bool) -> str:
     """Expands contractions in a sentence.
 
     Parameters
@@ -189,6 +188,12 @@ def replace_contractions(sentence: str, **kwargs) -> str:
     sentence : str
         with contracted words
 
+    Other Parameters
+    ----------------
+    **kwargs : bool
+        additional properties of the below method:
+            - contractions.fix()
+
     Returns
     -------
     str
@@ -205,7 +210,9 @@ def replace_contractions(sentence: str, **kwargs) -> str:
 
 
 def stem(
-    tokens: List[str], stemmer_type: Optional[str] = "nltk_porter_stemmer", **kwargs
+    tokens: List[str],
+    stemmer_type: Optional[str] = "nltk_porter_stemmer",
+    **kwargs: Any,
 ) -> List[str]:
     """Reduces tokens to their root (base) form.
 
@@ -226,12 +233,12 @@ def stem(
 
     Other Parameters
     ----------------
-    **kwargs : additional properties of the below stemmers:
-
-      - nltk.PorterStemmer
-      - nltk.LancasterStemmer
-      - nltk.RegexpStemmer
-      - nltk.SnowballStemmer
+    **kwargs : Any
+        additional properties of the below stemmers:
+          - nltk.PorterStemmer
+          - nltk.LancasterStemmer
+          - nltk.RegexpStemmer
+          - nltk.SnowballStemmer
 
     Returns
     -------
@@ -245,7 +252,6 @@ def stem(
     >>> stem(tokens, stemmer_type="nltk_porter_stemmer")
     ['I', 'like', 'drive', 'a', 'car']
     """
-
     if stemmer_type == "nltk_porter_stemmer":
         stemmer = PorterStemmer(**kwargs)
     elif stemmer_type == "nltk_lancaster_stemmer":
@@ -258,25 +264,19 @@ def stem(
     return [stemmer.stem(word) for word in tokens]
 
 
-def lemmatize(
-    tokens: List[str],
-    **kwargs,
-) -> List[str]:
-    """Lemmatize tokens using NLTK's WordNetLemmatizer
+def lemmatize(tokens: List[str], **kwargs: Any) -> List[str]:
+    """Lemmatizes tokens using NLTK's WordNetLemmatizer
 
     Parameters
     ----------
     tokens : List[str]
         list of tokens containing words with various inflectional forms
 
-    num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
-
     Other Parameters
     ----------------
-    **kwargs : additional properties of the below lemmatizer:
-
-      - nltk.WordNetLemmatizer
+    **kwargs : Any
+        additional properties of the below lemmatizer:
+          - nltk.WordNetLemmatizer
 
     Returns
     -------
@@ -302,7 +302,6 @@ def batch_lowercase_text(documents: List[str]) -> List[str]:
     documents : List[str]
         list of sentences with characters of arbitrary size
 
-
     Returns
     -------
     List[str]
@@ -336,20 +335,14 @@ def batch_lowercase_text(documents: List[str]) -> List[str]:
     return [document.lower() for document in documents]
 
 
-def batch_remove_non_ascii_characters(
-    documents: List[str],
-    num_workers: Optional[int] = None,
-) -> List[str]:
-    """Removes non-ascii characters from sentences in a concurrent manner.
+def batch_remove_non_ascii_characters(documents: List[str]) -> List[str]:
+    """Removes non-ascii characters from sentences.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences with non-ascii characters
 
-    num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
-
     Returns
     -------
     List[str]
@@ -369,7 +362,7 @@ def batch_remove_non_ascii_characters(
     ...     "This is a \xA9 but not a \xAE"
     ...     "fractions \xBC, \xBD, \xBE"
     ... ]
-    >>> batch_remove_non_ascii_characters(corpus, num_workers=2)
+    >>> batch_remove_non_ascii_characters(corpus)
     [
         'https://sitebulb.com/Folder/.html?',
         'Jreskog bichen Zrcher',
@@ -380,31 +373,22 @@ def batch_remove_non_ascii_characters(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(
-            remove_non_ascii_characters, documents, num_workers=num_workers
-        ),
-    )
+    return [remove_non_ascii_characters(doc) for doc in documents]
 
 
-def batch_replace_contractions(
-    documents: List[str], num_workers: Optional[int] = None, **kwargs
-) -> List[str]:
-    """Expands the contractions in sentences in a concurrent manner.
+def batch_replace_contractions(documents: List[str], **kwargs: bool) -> List[str]:
+    """Expands contractions in sentences.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences with contracted words
 
-    num_workers : Optional[int]
-        number of processors to use, by default None (all processors)
-
     Other Parameters
     ----------------
-    **kwargs : additional properties of the below method:
-      - contractions.fix()
+    **kwargs : bool
+        additional properties of the below method:
+          - contractions.fix()
 
     Returns
     -------
@@ -425,7 +409,7 @@ def batch_replace_contractions(
     ...     "I'll see you next week",
     ...     "I'm going for a walk"
     ... ]
-    >>> batch_replace_contractions(corpus, num_workers=2)
+    >>> batch_replace_contractions(corpus)
     [
         'I do not want to be rude, but you should not do this',
         'Do you think he will pass his driving test?',
@@ -436,36 +420,27 @@ def batch_replace_contractions(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(
-            replace_contractions, documents, num_workers=num_workers, **kwargs
-        ),
-    )
+    return [replace_contractions(doc, **kwargs) for doc in documents]
 
 
 def batch_remove_stopwords(
     tokens: List[List[str]],
     custom_stopwords: List[str] = [],
-    num_workers: Optional[int] = None,
 ) -> List[List[str]]:
-    """Removes stopwords from lists of tokens in a concurrent manner.
+    """Removes stopwords from nested token lists.
 
     Parameters
     ----------
     tokens : List[List[str]]
-        list of lists of tokens with stopwords
+        nested token lists with stopwords included
 
     custom_stopwords: List[str], optional
         list of stopwords to remove from sentences, by default []
 
-    num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
-
     Returns
     -------
     List[List[str]]
-        list of lists of tokens without stopwords
+        nested token lists without stopwords
 
     Raises
     ------
@@ -481,7 +456,7 @@ def batch_remove_stopwords(
     ...     ['This', 'guy', 's', 'name', 'is', 'Edward', 'Scissorhands'],
     ...     ['And', 'this', 'is', 'Tom', 'Parker']
     ... ]
-    >>> batch_remove_stopwords(corpus, num_workers=2)
+    >>> batch_remove_stopwords(corpus)
     [
         ['My', 'name', 'Dr', 'Jekyll'],
         ['His', 'name', 'Mr', 'Hyde'],
@@ -492,22 +467,14 @@ def batch_remove_stopwords(
     if not _is_nested_string_list(tokens):
         raise ValueError("'tokens' should be a list of nested string lists")
 
-    return cast(
-        List[List[str]],
-        _parallelize_func(
-            remove_stopwords,
-            tokens,
-            custom_stopwords=custom_stopwords,
-            num_workers=num_workers,
-        ),
-    )
+    return [remove_stopwords(token_list, custom_stopwords) for token_list in tokens]
 
 
 def batch_stem(
     tokens: List[List[str]],
     stemmer_type: Optional[str] = "nltk_porter_stemmer",
     num_workers: Optional[int] = None,
-    **kwargs,
+    **kwargs: Any,
 ) -> List[List[str]]:
     """Stems tokens in lists of tokens to their root (base) form in a
     concurrent manner.
@@ -533,12 +500,12 @@ def batch_stem(
 
     Other Parameters
     ----------------
-    **kwargs : additional properties of the below stemmers:
-
-      - nltk.PorterStemmer
-      - nltk.LancasterStemmer
-      - nltk.RegexpStemmer
-      - nltk.SnowballStemmer
+    **kwargs : Any
+        additional properties of the below stemmers:
+          - nltk.PorterStemmer
+          - nltk.LancasterStemmer
+          - nltk.RegexpStemmer
+          - nltk.SnowballStemmer
 
     Returns
     -------
@@ -589,7 +556,7 @@ def batch_stem(
 def batch_lemmatize(
     tokens: List[List[str]],
     num_workers: Optional[int] = None,
-    **kwargs,
+    **kwargs: Any,
 ) -> List[List[str]]:
     """Lemmatizes tokens in lists of tokens in a concurrent manner using
     NLTK WordNetLemmatizer.
@@ -597,22 +564,22 @@ def batch_lemmatize(
     Parameters
     ----------
     tokens : List[List[str]]
-        list of lists of tokens containing words with various
+        nested token lists containing tokens with various
         inflectional forms
 
     num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
+        number of logical processors to use, by default None (all)
 
     Other Parameters
     ----------------
-    **kwargs : additional properties of the below lemmatizer:
-
-      - nltk.WordNetLemmatizer
+    **kwargs : Any
+        additional properties of the below lemmatizer:
+          - nltk.WordNetLemmatizer
 
     Returns
     -------
     List[List[str]]
-        list of lists of lemmatized tokens
+        nested token lists with lemmatized tokens
 
     Raises
     ------
@@ -645,19 +612,14 @@ def batch_lemmatize(
     )
 
 
-def batch_remove_punctuation(
-    documents: List[str], num_workers: Optional[int] = None
-) -> List[str]:
-    """Removes punctuation characters from all sentences in a concurrent manner.
+def batch_remove_punctuation(documents: List[str]) -> List[str]:
+    """Removes punctuation characters from all sentences.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences which contain punctuation characters
 
-    num_workers : Optional[int]
-        number of processors to use, by default None (all processors)
-
     Returns
     -------
     List[str]
@@ -677,10 +639,7 @@ def batch_remove_punctuation(
     ...     "Is his name Edward Scissorhands?",
     ...     "This is Tom-Parker!"
     ... ]
-    >>> batch_remove_punctuation(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
+    >>> batch_remove_punctuation(corpus)
     [
         'My name is Dr Jekyll',
         'His name is Mr Hyde',
@@ -691,25 +650,17 @@ def batch_remove_punctuation(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(remove_punctuation, documents, num_workers=num_workers),
-    )
+    return [remove_punctuation(doc) for doc in documents]
 
 
-def batch_remove_numbers(
-    documents: List[str], num_workers: Optional[int] = None
-) -> List[str]:
-    """Removes numbers from all sentences in a concurrent manner.
+def batch_remove_numbers(documents: List[str]) -> List[str]:
+    """Removes numbers from all sentences.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences which contain numbers
 
-    num_workers : Optional[int]
-        number of processors to use, by default None (all processors)
-
     Returns
     -------
     List[str]
@@ -729,10 +680,7 @@ def batch_remove_numbers(
     ...     "I have 3 computers",
     ...     "He earns 1000$ daily"
     ... ]
-    >>> batch_remove_numbers(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
+    >>> batch_remove_numbers(corpus)
     [
         'He is  years old.',
         'His father has  cars',
@@ -743,25 +691,17 @@ def batch_remove_numbers(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(remove_numbers, documents, num_workers=num_workers),
-    )
+    return [remove_numbers(doc) for doc in documents]
 
 
-def batch_remove_whitespace(
-    documents: List[str], num_workers: Optional[int] = None
-) -> List[str]:
-    r"""Removes whitespace characters from all sentences in a concurrent manner.
+def batch_remove_whitespace(documents: List[str]) -> List[str]:
+    r"""Removes whitespace characters from all sentences.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences which contain whitespace characters
 
-    num_workers : Optional[int]
-        number of processors to use, by default None (all processors)
-
     Returns
     -------
     List[str]
@@ -781,10 +721,7 @@ def batch_remove_whitespace(
     ...     "I Am Hungry - Can We\t Eat Now, Please?",,
     ...     "It Is \r\nFreezing Outside!"
     ... ]
-    >>> batch_remove_whitespace(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
+    >>> batch_remove_whitespace(corpus)
     [
         'He Has Not Been in Touch for over a Month.',
         'I Will See You next Week',
@@ -795,10 +732,7 @@ def batch_remove_whitespace(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(remove_whitespace, documents, num_workers=num_workers),
-    )
+    return [remove_whitespace(doc) for doc in documents]
 
 
 def batch_convert_numerals_to_numbers(
@@ -812,7 +746,7 @@ def batch_convert_numerals_to_numbers(
         list of sentences which contain numerals
 
     num_workers : Optional[int]
-        number of processors to use, by default None (all processors)
+        number of logical processors to use, by default None (all)
 
     Returns
     -------
@@ -835,10 +769,7 @@ def batch_convert_numerals_to_numbers(
     ...     "Behind the eight ball",
     ...     "Between two stools",
     ... ]
-    >>> batch_convert_numerals_to_numbers(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
+    >>> batch_convert_numerals_to_numbers(corpus, num_workers=2)
     [
         'A bunch of 5',
         'A picture is worth a 1000 words',
